@@ -14,8 +14,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from .test_arguments import TestArguments
-from .test_login import TestLogin
-from .test_prometheus import TestPrometheus
-from .test_scrape import TestScrape
-from .test_server import TestServer
+from .mock_sshclient import MockSSHClient
+
+import paramiko.client
+
+paramiko.client.SSHClient = MockSSHClient
+
+from .test_arguments import TestArguments  # noqa
+from .test_login import TestLogin  # noqa
+from .test_prometheus import TestPrometheus  # noqa
+from .test_scrape import TestScrape  # noqa
+from .test_server import TestServer  # noqa
