@@ -19,36 +19,26 @@ import http.server
 
 from .login import login, logout
 from .prometheus import prometheus
-from .scrape import scrape_xdsl, scrape_traffic
+from .scrape import scrape_ifconfig, scrape_xdsl
 
 
 class Scraper:
     def __init__(self, args):
         self.args = args
         self.session = None
-        self.sessionkey = None
-        self.login_time = None
 
     def scrape(self):
-        # Log out and start a new session every 30 seconds to avoid a bug
-        # that locks the user out of the router.
-        if self.login_time is not None and \
-                (datetime.utcnow() - self.login_time).total_seconds() > 30*60:
-            logout(self.session, self.args.host, self.sessionkey)
-            self.session, self.sessionkey, self.login_time = None, None, None
-
         if self.session is None:
-            self.session, self.sessionkey = login(self.args.host,
-                                                  self.args.user,
-                                                  self.args.passwd)
-            self.login_time = datetime.utcnow()
+            self.session = login(self.args.host,
+                                 self.args.user,
+                                 self.args.passwd)
 
-        xdsl = scrape_xdsl(self.session, self.args.host) \
+        xdsl = scrape_xdsl(self.session) \
             if not self.args.traffic_only else None
-        traffic = scrape_traffic(self.session, self.args.host) \
+        ifconfig = scrape_ifconfig(self.session) \
             if not self.args.xdsl_only else None
 
-        return xdsl, traffic
+        return xdsl, ifconfig
 
 
 class Handler(http.server.BaseHTTPRequestHandler):
@@ -75,11 +65,11 @@ class Handler(http.server.BaseHTTPRequestHandler):
 </html>""".encode("utf8"))
 
     def send_metrics(self):
-        xdsl, traffic = self.scraper.scrape()
+        xdsl, ifconfig = self.scraper.scrape()
 
         self.send_response(200)
         self.end_headers()
-        self.wfile.write(prometheus(xdsl, traffic).encode("utf8"))
+        self.wfile.write(prometheus(xdsl, ifconfig).encode("utf8"))
 
 
 def serve(args):  # pragma: no cover
